# ACE File Upload

Upload files to MinIO for use in brewlytics


Setup procedures:

In a terminal/console:

pip install ace-upload

Once ace_upload is installed declare:

python -m ace_upload



Input procedures:

1. Default location of connection: minio.dev.caoc.army

2. Requires a user provide an access key and password.

3. User will be prompted for their firstname initial and lastname.

4. The file path provided should be Absolute. All files and subdirectory files will be picked up.

5. User provides a name of the intended cloud director to upload to. 

6. Input Y to proceed and upload or N to cancel the upload process.







